@@ -3,6 +3,7 @@ import pickle
 from typing import List
 import numpy as np
 import pandas as pd
+from pandas.core.tools.datetimes import _guess_datetime_format_for_array
 from tqdm import tqdm
 
 from structured_data_profiling.data_tests import (
@@ -52,6 +53,7 @@ class DatasetProfiler:
         separator: str = ",",
         thousands: str = None,
         decimals: str = ".",
+        encoding: str = None,
     ):
         """
 
@@ -76,8 +78,17 @@ class DatasetProfiler:
             sep=separator,
             decimal=decimals,
             thousands=thousands,
+            encoding=encoding,
         )
 
+        self.io_meta = {
+            "compression": compression,
+            "separator": separator,
+            "thousands": thousands,
+            "decimals": decimals,
+            "encoding": encoding,
+        }
+
         self.path = df_path
 
         if primary_key is not None:
@@ -161,6 +172,20 @@ class DatasetProfiler:
         for i in tqdm(possible_dates.keys()):
             self.column_types[i] = possible_dates[i]
 
+        self.datetime_formats = {}
+        string_dates = [
+            i for i in self.column_types.keys() if self.column_types[i] == "string/date"
+        ]
+
+        for i in string_dates:
+            try:
+                format_time = _guess_datetime_format_for_array(
+                    self.reduced_data_sample[i].sample(10).values,
+                )
+                self.datetime_formats[i] = format_time
+            except:
+                self.datetime_formats[i] = "Could not infer datetime format"
+
         self.tests = None
         self.column_profiles = None
 
@@ -504,14 +529,17 @@ class DatasetProfiler:
         ]
         #
         print("Finding threshold columns...")
+        try:
+            deterministic_columns_binary, num_cols = find_deterministic_columns_binary(
+                self.reduced_data_sample,
+                column_search,
+            )
+            data_tests["deterministic_columns_binary"] = deterministic_columns_binary
+            to_drop = [i[0] for i in deterministic_columns_binary]
+        except:
+            data_tests["deterministic_columns_binary"] = []
+            to_drop = []
 
-        deterministic_columns_binary, num_cols = find_deterministic_columns_binary(
-            self.reduced_data_sample,
-            column_search,
-        )
-        data_tests["deterministic_columns_binary"] = deterministic_columns_binary
-
-        to_drop = [i[0] for i in deterministic_columns_binary]
         print("Finding linear combinations...")
 
         self.reduced_data_sample = self.reduced_data_sample.drop(to_drop, axis=1)
@@ -542,12 +570,14 @@ class DatasetProfiler:
         slices = find_slices(X, list_columns[-2:])
         self.data_slices = slices
 
-    def generate_expectations(self, docs=True):
+    def generate_expectations(self, docs=True, suite_name=None):
         import great_expectations as ge
 
+        if suite_name is None:
+            suite_name = self.path.split("/")[-1]
         data_context = ge.data_context.DataContext()
         suite = data_context.create_expectation_suite(
-            "local_suite",
+            suite_name,
             overwrite_existing=True,
         )
         batch = ge.dataset.PandasDataset(
@@ -583,8 +613,8 @@ class DatasetProfiler:
 
     def save(self, name: str):
 
-        for j, i in enumerate(self.data):
-            self.data[j] = []
+        # self.data_sample = []
+        # self.reduced_data_sample = []
 
         with open(name, "wb") as f:
             pickle.dump(self, f)
